@@ -1,8 +1,8 @@
 #! /bin/bash
 ## eicq-user-install.sh   -*-Shell-script-*-
-## $Id: eicq-user-install.sh,v 1.1 2000/08/16 08:25:56 young Exp $
+## $Id: eicq-user-install.sh,v 1.3 2001/03/06 07:39:22 youngs Exp $
 
-## Copyright (C) 2000 Steve Youngs
+## Copyright (C) 2000, 2001 Steve Youngs
 
 
 ## This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 # Variables and constants
 MKDIR=/bin/mkdir
 INSTALL=/usr/bin/install
-RCFILE=/usr/local/lib/xemacs/xemacs-packages/etc/eicq/world
+RCFILE=/usr/local/lib/xemacs/site-packages/etc/eicq/world
 RCDIR=${HOME}/.eicq
 
 # Code
